Learn R Programming

AllelicImbalance (version 1.6.2)

countAllelesFromBam: alleleCounts from bam file

Description

count alleles before creating ASEse.

Usage

countAllelesFromBam(gr, ...)
"countAllelesFromBam"(gr, pathToDir, flag = NULL, scanBamFlag = NULL, return.class = "array", verbose = TRUE)

Arguments

gr
GRanges that contains SNPs of interest
...
arguments to pass on
pathToDir
path to directory of bam files
flag
specify one flag to use as filter, default is no filtering. allowed flags are 99, 147, 83 and 163
scanBamFlag
set a custom flag to use as filter
return.class
type of class for the returned object
verbose
makes funciton more talkative

Details

counts the alleles in a bam file based on GRanges positions.

Examples

Run this code
data(GRvariants)
gr <- GRvariants

##not run at the moment
#pathToDir <- system.file('inst/extdata/ERP000101_subset', package='AllelicImbalance')
#ar <- countAllelesFromBam(gr, pathToDir)

Run the code above in your browser using DataLab