Learn R Programming

AllelicImbalance (version 1.6.2)

defaultMapBias: Generate default mapbias from genotype

Description

Create mapbias array from genotype matrix requires genotype information

Usage

defaultMapBias(x, ...)
"defaultMapBias"(x)

Arguments

x
ASEset object
...
internal arguments

Details

Default mapbias will be 0.5 for bi-allelic snps and 1 for homozygots. For genotypes with NA, 0.5 will be placed on all four alleles. Therefore tri-allelic can not be used atm. Genotype information has to be placed in the genotype(x) assay.

Examples

Run this code
#load example data
data(ASEset.sim)

fasta <- system.file('extdata/hg19.chr17.subset.fa', package='AllelicImbalance')
refAllele(ASEset.sim,fasta=fasta)
a <- refAllele(ASEset.sim,fasta=fasta)

Run the code above in your browser using DataLab