Learn R Programming

AllelicImbalance (version 1.8.3)

genofilters: genotype filter methods

Description

useful genotype filters

filter on multiallelic snps

Arguments

x
ASEset object
source
'genotype' or 'alleleCounts'
x
ASEset object
strand
strand to infer from
inferOver
'eachSample' or 'allSamples'
threshold.count.sample
least amount of counts to try to infer allele
threshold.frequency
least fraction to classify (see details)

Details

hetFilt returns TRUE if the samples is heterozygote, based on stored genotype information present in the phase data.

based on the allele counts for all four variants A, T, G and C and returns true if there is counts enough suggesting a third or more alleles. The sensitivity can be specified using 'threshold.count.sample' and 'threshold.frequency'.

Examples

Run this code
#load example data
data(ASEset)
a <- ASEset

genotype(a) <- inferGenotypes(a)
hets <- hetFilt(a)
#load example data
data(ASEset)
a <- ASEset

multiAllelicFilt(a)

Run the code above in your browser using DataLab