inference of the alternate allele based on count data
Arguments
x
matrix see examples
return.class
class of returned object
...
arguments to forward to internal functions
Details
The inference essentially ranks all alleles and the most expressed allele not
declared as reference will be inferred as the alternative allele. At the moment only inference of
bi-allelic alternative alleles are available.