hetFilt returns TRUE if the samples is heterozygote, based on stored genotype information
present in the phase data.
based on the allele counts for all four variants A, T, G and C and returns true
if there is counts enough suggesting a third or more alleles. The sensitivity can
be specified using 'threshold.count.sample' and 'threshold.frequency'.
#load example datadata(ASEset)
a <- ASEset
genotype(a) <- inferGenotypes(a)
hets <- hetFilt(a)
#load example datadata(ASEset)
a <- ASEset
multiAllelicFilt(a)